Fix spelling of "accordion".

Bump version.
diff --git a/CHANGES.md b/CHANGES.md
index ce57fe2..4d3151b 100644
--- a/CHANGES.md
+++ b/CHANGES.md
@@ -1,7 +1,13 @@
-CHANGES - 2.3.0 - 2019-08-23
+CHANGES - 2.3.1 - 2019-08-27
 ============================
 
 
+Changes in CUPS v2.3.1
+----------------------
+
+- Fixed spelling of "fold-accordion".
+
+
 Changes in CUPS v2.3.0
 ----------------------
 
diff --git a/configure b/configure
index d3df145..ac0646f 100755
--- a/configure
+++ b/configure
@@ -1,6 +1,6 @@
 #! /bin/sh
 # Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.69 for CUPS 2.3.0.
+# Generated by GNU Autoconf 2.69 for CUPS 2.3.1.
 #
 # Report bugs to <https://github.com/apple/cups/issues>.
 #
@@ -580,8 +580,8 @@
 # Identity of this package.
 PACKAGE_NAME='CUPS'
 PACKAGE_TARNAME='cups'
-PACKAGE_VERSION='2.3.0'
-PACKAGE_STRING='CUPS 2.3.0'
+PACKAGE_VERSION='2.3.1'
+PACKAGE_STRING='CUPS 2.3.1'
 PACKAGE_BUGREPORT='https://github.com/apple/cups/issues'
 PACKAGE_URL='https://www.cups.org/'
 
@@ -1467,7 +1467,7 @@
   # Omit some internal or obsolete options to make the list less imposing.
   # This message is too long to be a string in the A/UX 3.1 sh.
   cat <<_ACEOF
-\`configure' configures CUPS 2.3.0 to adapt to many kinds of systems.
+\`configure' configures CUPS 2.3.1 to adapt to many kinds of systems.
 
 Usage: $0 [OPTION]... [VAR=VALUE]...
 
@@ -1532,7 +1532,7 @@
 
 if test -n "$ac_init_help"; then
   case $ac_init_help in
-     short | recursive ) echo "Configuration of CUPS 2.3.0:";;
+     short | recursive ) echo "Configuration of CUPS 2.3.1:";;
    esac
   cat <<\_ACEOF
 
@@ -1713,7 +1713,7 @@
 test -n "$ac_init_help" && exit $ac_status
 if $ac_init_version; then
   cat <<\_ACEOF
-CUPS configure 2.3.0
+CUPS configure 2.3.1
 generated by GNU Autoconf 2.69
 
 Copyright (C) 2012 Free Software Foundation, Inc.
@@ -2177,7 +2177,7 @@
 This file contains any messages produced by compilers while
 running configure, to aid debugging if configure makes a mistake.
 
-It was created by CUPS $as_me 2.3.0, which was
+It was created by CUPS $as_me 2.3.1, which was
 generated by GNU Autoconf 2.69.  Invocation command line was
 
   $ $0 $@
@@ -2694,7 +2694,7 @@
 ac_config_headers="$ac_config_headers config.h"
 
 
-CUPS_VERSION="2.3.0"
+CUPS_VERSION="2.3.1"
 CUPS_REVISION=""
 CUPS_BUILD="cups-$CUPS_VERSION"
 
@@ -10393,7 +10393,7 @@
 # report actual input values of CONFIG_FILES etc. instead of their
 # values after options handling.
 ac_log="
-This file was extended by CUPS $as_me 2.3.0, which was
+This file was extended by CUPS $as_me 2.3.1, which was
 generated by GNU Autoconf 2.69.  Invocation command line was
 
   CONFIG_FILES    = $CONFIG_FILES
@@ -10456,7 +10456,7 @@
 cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
 ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
 ac_cs_version="\\
-CUPS config.status 2.3.0
+CUPS config.status 2.3.1
 configured by $0, generated by GNU Autoconf 2.69,
   with options \\"\$ac_cs_config\\"
 
diff --git a/configure.ac b/configure.ac
index 7eca9e3..23abe87 100644
--- a/configure.ac
+++ b/configure.ac
@@ -12,7 +12,7 @@
 AC_PREREQ(2.60)
 
 dnl Package name and version...
-AC_INIT([CUPS], [2.3.0], [https://github.com/apple/cups/issues], [cups], [https://www.cups.org/])
+AC_INIT([CUPS], [2.3.1], [https://github.com/apple/cups/issues], [cups], [https://www.cups.org/])
 
 sinclude(config-scripts/cups-opsys.m4)
 sinclude(config-scripts/cups-common.m4)
diff --git a/cups/cups.h b/cups/cups.h
index e64fdcc..77a66c1 100644
--- a/cups/cups.h
+++ b/cups/cups.h
@@ -42,10 +42,10 @@
  * Constants...
  */
 
-#  define CUPS_VERSION			2.0300
+#  define CUPS_VERSION			2.0301
 #  define CUPS_VERSION_MAJOR		2
 #  define CUPS_VERSION_MINOR		3
-#  define CUPS_VERSION_PATCH		0
+#  define CUPS_VERSION_PATCH		1
 
 #  define CUPS_BC_FD			3
 					/* Back-channel file descriptor for
diff --git a/cups/ipp-support.c b/cups/ipp-support.c
index 7d028b4..192f5b6 100644
--- a/cups/ipp-support.c
+++ b/cups/ipp-support.c
@@ -460,7 +460,7 @@
 		  "punch-multiple-top",	/* IPP Finishings 2.1/Canon */
 		  "punch-multiple-right",/* IPP Finishings 2.1/Canon */
 		  "punch-multiple-bottom",/* IPP Finishings 2.1/Canon */
-		  "fold-accordian",	/* IPP Finishings 2.0 */
+		  "fold-accordion",	/* IPP Finishings 2.0 */
 		  "fold-double-gate",	/* IPP Finishings 2.0 */
 		  "fold-gate",		/* IPP Finishings 2.0 */
 		  "fold-half",		/* IPP Finishings 2.0 */
@@ -571,7 +571,7 @@
 		  "0x40000057",
 		  "0x40000058",
 		  "0x40000059",
-		  "cups-fold-accordian",
+		  "cups-fold-accordion",
 		  "cups-fold-double-gate",
 		  "cups-fold-gate",
 		  "cups-fold-half",
diff --git a/vcnet/config.h b/vcnet/config.h
index ad69190..993470f 100644
--- a/vcnet/config.h
+++ b/vcnet/config.h
@@ -89,8 +89,8 @@
  * Version of software...
  */
 
-#define CUPS_SVERSION "CUPS v2.3.0"
-#define CUPS_MINIMAL "CUPS/2.3.0"
+#define CUPS_SVERSION "CUPS v2.3.1"
+#define CUPS_MINIMAL "CUPS/2.3.1"
 
 
 /*
diff --git a/xcode/config.h b/xcode/config.h
index 13198f5..ea60351 100644
--- a/xcode/config.h
+++ b/xcode/config.h
@@ -18,8 +18,8 @@
  * Version of software...
  */
 
-#define CUPS_SVERSION "CUPS v2.3.0"
-#define CUPS_MINIMAL "CUPS/2.3.0"
+#define CUPS_SVERSION "CUPS v2.3.1"
+#define CUPS_MINIMAL "CUPS/2.3.1"
 
 
 /*
diff --git a/cups/ipp.h b/cups/ipp.h
index 6402855..1f2fd8e 100644
--- a/cups/ipp.h
+++ b/cups/ipp.h
@@ -149,7 +149,7 @@
   IPP_FINISHINGS_PUNCH_MULTIPLE_TOP,	/* Pucnh multiple holes top edge */
   IPP_FINISHINGS_PUNCH_MULTIPLE_RIGHT,	/* Pucnh multiple holes right side */
   IPP_FINISHINGS_PUNCH_MULTIPLE_BOTTOM,	/* Pucnh multiple holes bottom edge */
-  IPP_FINISHINGS_FOLD_ACCORDIAN = 90,	/* Accordian-fold the paper vertically into four sections */
+  IPP_FINISHINGS_FOLD_ACCORDION = 90,	/* Accordion-fold the paper vertically into four sections */
   IPP_FINISHINGS_FOLD_DOUBLE_GATE,	/* Fold the top and bottom quarters of the paper towards the midline, then fold in half vertically */
   IPP_FINISHINGS_FOLD_GATE,		/* Fold the top and bottom quarters of the paper towards the midline */
   IPP_FINISHINGS_FOLD_HALF,		/* Fold the paper in half vertically */
@@ -184,8 +184,8 @@
   IPP_FINISHINGS_CUPS_PUNCH_QUAD_RIGHT,	/* Punch 4 holes right side @exclude all@ */
   IPP_FINISHINGS_CUPS_PUNCH_QUAD_BOTTOM,/* Punch 4 holes bottom edge @exclude all@ */
 
-  IPP_FINISHINGS_CUPS_FOLD_ACCORDIAN = 0x4000005A,
-					/* Accordian-fold the paper vertically into four sections @exclude all@ */
+  IPP_FINISHINGS_CUPS_FOLD_ACCORDION = 0x4000005A,
+					/* Accordion-fold the paper vertically into four sections @exclude all@ */
   IPP_FINISHINGS_CUPS_FOLD_DOUBLE_GATE,	/* Fold the top and bottom quarters of the paper towards the midline, then fold in half vertically @exclude all@ */
   IPP_FINISHINGS_CUPS_FOLD_GATE,	/* Fold the top and bottom quarters of the paper towards the midline @exclude all@ */
   IPP_FINISHINGS_CUPS_FOLD_HALF,	/* Fold the paper in half vertically @exclude all@ */
@@ -198,8 +198,10 @@
   IPP_FINISHINGS_CUPS_FOLD_Z		/* Fold the paper vertically into three sections, forming a Z @exclude all@ */
 } ipp_finishings_t;
 #  ifndef _CUPS_NO_DEPRECATED
+#    define IPP_FINISHINGS_CUPS_FOLD_ACCORDIAN IPP_FINISHINGS_CUPS_FOLD_ACCORDION
+#    define IPP_FINISHINGS_FOLD_ACCORDIAN IPP_FINISHINGS_FOLD_ACCORDION
 #    define IPP_FINISHINGS_JOB_OFFSET	IPP_FINISHINGS_JOG_OFFSET
-					/* Long-time misspelling... */
+					/* Long-time misspellings... */
 typedef enum ipp_finishings_e ipp_finish_t;
 #  endif /* !_CUPS_NO_DEPRECATED */
 